@@ -123,7 +123,7 @@ class LicenseDto:
         if not isinstance(self.user, Unset):
             user = self.user.to_dict()
 
-        reseller: Union[Unset, Dict[str, Any]] = UNSET
+        reseller: Union[Unset, None, Dict[str, Any]] = UNSET
         if not isinstance(self.reseller, Unset):
             reseller = self.reseller.to_dict()
 
@@ -408,8 +408,10 @@ class LicenseDto:
             user = UserDto.from_dict(_user)
 
         _reseller = d.pop("reseller", UNSET)
-        reseller: Union[Unset, UserDto]
-        if isinstance(_reseller, Unset):
+        reseller: Union[Unset, None, UserDto]
+        if _reseller is None:
+            reseller = None
+        elif isinstance(_reseller, Unset):
             reseller = UNSET
         else:
             reseller = UserDto.from_dict(_reseller)
